vfbLib.ufo
==========

.. automodule:: vfbLib.ufo
  
   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :template: custom-module-template.rst
   :recursive:

   builder
   designspace
   features
   glyph
   groups
   guides
   info
   kerning
   paths
   pshints
   time
   tth
   typing
   vfb2ufo

